<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/entity/RImageEntity.cpp" line="+86"/>
        <source>File</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
&amp;Fichier
Fichier
Création d&apos;un nouveau fichier...</translatorcomment>
        <translation>Fichier</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+69"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
Indiquer la position de la ligne de cote ou un angle :
Indiquer la position de la ligne de cote ou un angle
Indiquer la position [angle/longueur]</translatorcomment>
        <translation>Position</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width Factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Facteur de largeur</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height Factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Facteur de hauteur</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+124"/>
        <source>Width</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
Largeur&#xa0;: 
Largeur
&amp;Largeur de page :</translatorcomment>
        <translation>Largeur</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <source>Height</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
Hauteur&#xa0;: 
Hauteur
&amp;Hauteur de page :</translatorcomment>
        <translation>Hauteur</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Fade</source>
        <translation>Fondu</translation>
    </message>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="+87"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+75"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+101"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimAngular3PEntity.cpp" line="+97"/>
        <location line="+16"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+93"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="+97"/>
        <location line="+16"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="+99"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="+98"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="+99"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="+97"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+87"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+79"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+89"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-12"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+76"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+82"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="-2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-19"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+77"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+86"/>
        <location line="+3"/>
        <location line="+8"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+77"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>X</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
Sortie de l&apos;application...
Sortie de l&apos;application
Exportation du dessin...</translatorcomment>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngular3PEntity.cpp" line="-16"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="-16"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-16"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
&amp;Centre, point, angles
Centre, point, angles
Indiquer le centre</translatorcomment>
        <translation>Centre</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="-1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimAngular3PEntity.cpp" line="-1"/>
        <location line="+16"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="-1"/>
        <location line="+16"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-1"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-1"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-14"/>
        <location line="+3"/>
        <location line="+8"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Y</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
&amp;Modifier
Modifier
&amp;Calque</translatorcomment>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimAngular3PEntity.cpp" line="-15"/>
        <location line="+16"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="-15"/>
        <location line="+16"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-14"/>
        <location line="+3"/>
        <location line="+8"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Z</source>
        <translatorcomment>--google--
Partage &amp;Horizontal
Partage Horizontal
&amp;Horizontale</translatorcomment>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <source>Radius</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
Indiquer le rayon
Centre, &amp;rayon</translatorcomment>
        <translation>Rayon</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-9"/>
        <source>Start Angle</source>
        <translatorcomment>--ignored case--
--file: ArcCPA_fr.ts--
Indiquer l&apos;angle de départ :
Indiquer l&apos;angle de départ</translatorcomment>
        <translation>Angle de départ</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>End Angle</source>
        <translatorcomment>--ignored case--
--file: ArcCPA_fr.ts--
Indiquer l&apos;angle de fin ou [Longueur de corde/Angle]
Indiquer l&apos;angle d&apos;arrivée</translatorcomment>
        <translation>Angle d&apos;arrivée</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>Reversed</source>
        <translatorcomment>--exact match--
--file: qcadlib_fr.ts--
Inversé</translatorcomment>
        <translation>Inversé</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+9"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+2"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+3"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+10"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+2"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-10"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+2"/>
        <source>Length</source>
        <translatorcomment>--exact match--
--file: LineRelativeAngle_fr.ts--
Longueur de corde incorrecte
Indiquer l&apos;angle de fin ou [Longueur de corde/Angle]</translatorcomment>
        <translation>Longueur</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <source>Total Length</source>
        <translation>Longueur totale:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sweep Angle</source>
        <translation>Angle</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+2"/>
        <source>Total Area</source>
        <translation>Superficie totale</translation>
    </message>
    <message>
        <source>Contents</source>
        <translatorcomment>--exact match--
--file: assistant_fr.ts--
Colle le contenu du Presse-papiers
Modifier le contenu du bloc sélectionné</translatorcomment>
        <translation type="obsolete">Sommaire</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="-12"/>
        <source>Solid</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
Dessine des hachures et des remplissages unis
Remplissage uni</translatorcomment>
        <translation>Trait continu</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Pattern</source>
        <translatorcomment>--exact match--
--file: Hatch_fr.ts--
Motif
Motifs de &amp;hachure :</translatorcomment>
        <translation>Motif</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Name</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
document non nommé %1
Enregistrement du dessin sous un nouveau nom...
Enregistrement du dessin sous un nouveau nom</translatorcomment>
        <translation>Nom</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>From Entity</source>
        <translation>De entité</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+8"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+2"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <source>Angle</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
Angle :
Angle
Indiquer l&apos;angle de la ligne de cote :</translatorcomment>
        <translation>Angle</translation>
    </message>
    <message>
        <location line="+192"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+13"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-191"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+2"/>
        <source>Scale</source>
        <translatorcomment>--exact match--
--file: Scale_fr.ts--
&amp;Echelle
Echelle
Met les entités à l&apos;échelle</translatorcomment>
        <translation>Echelle</translation>
    </message>
    <message>
        <source>Simple</source>
        <translatorcomment>--google--
Texte simple</translatorcomment>
        <translation type="vanished">Simple</translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="vanished">Texte</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation type="vanished">Texte brut</translation>
    </message>
    <message>
        <source>Font Name</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Nom de police</translation>
    </message>
    <message>
        <source>Text Height</source>
        <translation type="vanished">Hauteur du texte</translation>
    </message>
    <message>
        <source>Text Angle</source>
        <translation type="vanished">Angle du texte</translation>
    </message>
    <message>
        <source>X Scale</source>
        <translation type="vanished">Echelle X</translation>
    </message>
    <message>
        <source>Bold</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
&amp;Gras
Gras</translatorcomment>
        <translation type="vanished">Gras</translation>
    </message>
    <message>
        <source>Italic</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
Italique
&amp;Italique</translatorcomment>
        <translation type="vanished">Italique</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translatorcomment>--google--
Espacement lignes :
Espace lignes par &amp;défaut
Espace lignes par défaut
Facteur espacement lignes</translatorcomment>
        <translation type="vanished">Espacement lignes</translation>
    </message>
    <message>
        <source>Alignment</source>
        <translatorcomment>--exact match--
--file: Text_fr.ts--
Alignement
Alignement|Vertical</translatorcomment>
        <translation type="vanished">Alignement</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
Partage &amp;Horizontal
Partage Horizontal
&amp;Horizontale</translatorcomment>
        <translation type="vanished">Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
&amp;Verticale
Vertical
Cotation verticale</translatorcomment>
        <translation type="vanished">Vertical</translation>
    </message>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="-5"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <source>Diameter</source>
        <translatorcomment>--exact match--
--file: Scripts_fr.ts--
Permuter le signe de diamètre
Diamètre</translatorcomment>
        <translation>Diamètre</translation>
    </message>
    <message>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <source>Circumference</source>
        <translatorcomment>--google--
Mesure l&apos;aire et la circonférence d&apos;un polygone
Circonférence : %1</translatorcomment>
        <translation>Circonférence</translation>
    </message>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="+4"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+10"/>
        <source>Area</source>
        <translatorcomment>--google--
Aire &amp;polygonale
Mesure l&apos;aire et la circonférence d&apos;un polygone</translatorcomment>
        <translation>Zone</translation>
    </message>
    <message>
        <location filename="../src/entity/REllipseEntity.cpp" line="-17"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Major Point</source>
        <translatorcomment>--google--
Point principal|X
Point principal|Y
Point majeur de l&apos;ellipse ou le rayon grandes</translatorcomment>
        <translation>Point majeur</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ratio</source>
        <translatorcomment>--exact match--
--file: qcadlib_fr.ts--
Ratio
Dessine un arc elliptique du centre, le point majeur, le ratio et les angles</translatorcomment>
        <translation>Ratio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start Parameter</source>
        <translatorcomment>--ignored case--
--file: EllipseArcCPPA_fr.ts--
Paramètre de démarrage</translatorcomment>
        <translation>Paramètre de démarrage</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Parameter</source>
        <translatorcomment>--ignored case--
--file: EllipseArcCPPA_fr.ts--
Paramètre de fin</translatorcomment>
        <translation>Paramètre de fin</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-7"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Point</source>
        <translatorcomment>--ignored case--
--file: PointNP_fr.ts--
Point de départ (x) :
Point de départ (x)
Point de départ (y) :</translatorcomment>
        <translation>Point de départ</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Point</source>
        <translatorcomment>--ignored case--
--file: PointNP_fr.ts--
Extrémité (y) :
Extrémité (y)
Extrémité (x) :</translatorcomment>
        <translation>Point final</translation>
    </message>
    <message>
        <source>Clockwise</source>
        <translation type="vanished">Sens horaire</translation>
    </message>
    <message>
        <source>Counterclockwise</source>
        <translation type="vanished">Antihorairement</translation>
    </message>
    <message>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-16"/>
        <source>Polyline Pattern</source>
        <translation>Motif polyligne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Closed</source>
        <translatorcomment>--exact match--
--file: SplineControlPoints_fr.ts--
Impossible d&apos;ajouter à la fin d&apos;une polyligne fermée.
Impossible d&apos;ajouter à la fin d&apos;une polyligne fermée
Fermé</translatorcomment>
        <translation>Fermé</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Start Width</source>
        <translation>Largeur de départ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Width</source>
        <translation>Largeur d&apos;arrivée</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Width</source>
        <translation>Largeur globale</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orientation</source>
        <translation>Orientation</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Base Angle</source>
        <translation>Angle de base</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Global Z</source>
        <translation>Z globale</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-21"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+2"/>
        <location line="+1"/>
        <source>Vertex</source>
        <translatorcomment>--google--
Suivant vertex
Premier vertex</translatorcomment>
        <translation>Sommet</translation>
    </message>
    <message>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-4"/>
        <source>Bulge</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Renflement</translation>
    </message>
    <message>
        <location filename="../src/entity/RSplineEntity.cpp" line="-10"/>
        <source>Closed Periodic</source>
        <translation>Fermé périodique</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translatorcomment>--exact match--
--file: Scripts_fr.ts--
Degrés décimaux
Degré :</translatorcomment>
        <translation>Degré</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Control Point</source>
        <translatorcomment>--google--
Indiquer le premier point de contrôle
Indiquer le point de contrôle suivant ou [%1]
Indiquer le point de contrôle suivant</translatorcomment>
        <translation>Point de contrôle</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Fit Point</source>
        <translatorcomment>--google--
Premier point ajustement
Point ajustement suivant
&amp;Spline (points d&apos;ajustement)</translatorcomment>
        <translation>Point ajustement</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Knot Vector</source>
        <translation>Vecteur de noeud</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Knot</source>
        <translation>Noeud</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Use Start Tangent</source>
        <translation>Utiliser la tangente de départ</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Tangent</source>
        <translation>Tangente de départ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use End Tangent</source>
        <translation>Utiliser la tangente d&apos;arrivée</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Tangent</source>
        <translation>Tangente d&apos;arrivée</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Line</source>
        <translatorcomment>--google--
Indiquer l&apos;emplacement de la ligne de cote
Indiquer l&apos;angle de la ligne de cote :
Indiquer l&apos;angle de la ligne de cote</translatorcomment>
        <translation>Ligne de cote</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 1</source>
        <translatorcomment>--google--
Point d&apos;attache 1|X
Point d&apos;attache 1|Y</translatorcomment>
        <translation>Point d&apos;attache 1</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 2</source>
        <translatorcomment>--google--
Point d&apos;attache 2|X
Point d&apos;attache 2|Y</translatorcomment>
        <translation>Point d&apos;attache 2</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ligne 1 départ</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 End</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ligne 1 fin</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ligne 2 départ</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 End</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ligne 2 fin</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular3PEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Arc</source>
        <translatorcomment>--google--
Indiquer l&apos;emplacement de la ligne d&apos;arc de cote
Emplacement de l&apos;arc dimension</translatorcomment>
        <translation>Arc de cote</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-6"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Chord Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Point de corde</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Far Chord Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Point de corde loin</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-5"/>
        <location line="+1"/>
        <source>Origin</source>
        <translatorcomment>--google--
Indiquer l&apos;origine de la première ligne d&apos;attache
Indiquer l&apos;origine de la seconde ligne d&apos;attache
&amp;Supprimer original</translatorcomment>
        <translation>Origine</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate</source>
        <translatorcomment>--exact match--
--file: qcadactions_fr.ts--
&amp;Ordonnée
Ordonnée
Cotation ordonnée</translatorcomment>
        <translation>Ordonnée</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Defining Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Point déterminant</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Leader End Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Repère point final</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimRotatedEntity.cpp" line="+115"/>
        <source>Dimension Angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Angle de cotation</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-21"/>
        <source>Label</source>
        <translatorcomment>--exact match--
--file: Dimension_fr.ts--
Etiquette :
Etiquette
Indiquer l&apos;étiquette fixe ou laisser vide pour l&apos;étiquette automatique</translatorcomment>
        <translation>Etiquette</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Tolerance</source>
        <translatorcomment>--exact match--
--file: SelectContour_fr.ts--
Tolérance supérieure
Tolérance inférieure</translatorcomment>
        <translation>Tolérance</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Upper Limit</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Limite supérieure</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lower Limit</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Limite inférieure</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Definition Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Point de définition</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Position du texte</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Flip First Arrow</source>
        <translation>Miroir la première flèche</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Flip Second Arrow</source>
        <translation>Miroir la deuxième flèche</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Auto Label</source>
        <translation>Auto etiquette</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Measured Value</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Valeur mesurée</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear Factor</source>
        <translation>Facteur</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block Name</source>
        <translation>Nom du bloc</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Auto Label Position</source>
        <translation>Auto Label Position</translation>
    </message>
    <message>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-4"/>
        <source>Arrow</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
Repère (séquence de lignes avec flèche)
Taille de flèche :</translatorcomment>
        <translation>Flèche</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow Block</source>
        <translation>Flèche bloc</translation>
    </message>
    <message>
        <location filename="../src/entity/RFaceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 1</source>
        <translatorcomment>--google--
Point d&apos;attache 1|X
Point d&apos;attache 1|Y
Point 1|X</translatorcomment>
        <translation>Point 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 2</source>
        <translatorcomment>--google--
Point d&apos;attache 2|X
Point d&apos;attache 2|Y
Point 2|X</translatorcomment>
        <translation>Point 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 3</source>
        <translatorcomment>--google--
Point 3|X
Point 3|Y</translatorcomment>
        <translation>Point 3</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 4</source>
        <translatorcomment>--google--
Point 4|X
Point 4|Y</translatorcomment>
        <translation>Point 4</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeDefinitionEntity.cpp" line="+89"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+89"/>
        <source>Tag</source>
        <translation>Étiquette</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prompt</source>
        <translation>Invite</translation>
    </message>
    <message>
        <location filename="../src/entity/RRayEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Base Point</source>
        <translation>Point de base</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Second Point</source>
        <translation>Deuxième point</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction Vector</source>
        <translation>Direction</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+3"/>
        <source>Fixed Angle</source>
        <translation>Angle fixe</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+1"/>
        <source>Invisible</source>
        <translation>Invisible</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="+2"/>
        <source>Arc Symbol Type</source>
        <translation>Symbole d&apos;arc</translation>
    </message>
</context>
</TS>
